@@ -159,6 +159,10 @@ class Edit(Command):
                 self.args.eid
             )
         entry = entries[0]
+        # update the entry before editing it
+        entry.update()
+        collection.save_entries([entry])
+        # and then edit the updated file
         filepath = os.path.join(collection.itemdir, entry.fname)
         if edit_file_in_external_editor(filepath):
             collection.update_cache([filepath])
@@ -287,7 +291,11 @@ class Search(Command):
         offset = self.args.offset or 0
         pagesize = self.args.pagesize or 12
         collection = self.collection_class(self.args.collection)
-        if self.args.query == ['*']:
+        # sorted results require a less efficient full search rather
+        # than being able to use the list of all documents.
+        if self.args.query == ['*'] and not (
+                self.args.sort or collection.settings.default_sort
+        ):
             results = collection.get_all_documents()
         else:
             collection.start_search(
